# Rio Icons

This directory contains icons that ship with Rio. These come from various
sources, and this file serves to give credits and track licenses for each of
them.

## brand

These originate from [Bootstrap Icons](https://icons.getbootstrap.com/). They
include a good selection, and given their widespread use it's safe to say these
companies don't mind their logos being used in this context.

## custom-material-icons

This are additional icons following the style of Material Icons. They were
created by Rio developers and as such are thus available under the same license
as the rest of the project.

## file

The icons are created by the Rio project, and are available under the same
license as the rest of the project. **BUT** some of the icons contain logos
owned by other companies.

## rio

These contain Rio-specific logos and icons. They are created by the Rio project
and are available under the same license as the rest of the project.

## styling

Simple helper icons that can be used to style components. They are created by
the Rio project and are available under the same license as the rest of the
project.
